@@ -44,9 +44,3 @@ char *getname(char *);
 char *adrsprintf(char *, char *);
 char *auxformat(struct mailname *, int);
 struct mailname *getm(char *, char *, int, int, char *);
-
-char *LocalName(void);
-char *SystemName(void);
-char *UucpChan(void);
-char *OfficialName(char *);
-
