@@ -108,10 +108,10 @@
 #define bcpy(b1,b2,length)      memcmp (b1, b2, length)
 #define bzero(b,length)         memset (b, 0, length)
 
-#ifdef BSD42
-# define KILLPG(pid,sig) killpg(pid,sig);
+#ifdef HAVE_KILLPG
+# define KILLPG(pgrp,sig) killpg(pgrp,sig);
 #else
-# define KILLPG(pid,sig) kill(pid,sig);
+# define KILLPG(pgrp,sig) kill((-pgrp),sig);
 #endif
 
 /*
