@@ -14,10 +14,7 @@
 
 #include <h/mh.h>
 #include <zotnet/mts/mts.h>
-
-#ifdef SOCKETS
-# include <netdb.h>
-#endif
+#include <netdb.h>
 
 static struct host {
     char *h_name;
@@ -36,10 +33,7 @@ char *
 OfficialName (char *name)
 {
     char *p, *q, site[BUFSIZ];
-
-#ifdef SOCKETS
     struct hostent *hp;
-#endif
 
     static char buffer[BUFSIZ];
     char **r;
@@ -50,27 +44,17 @@ OfficialName (char *name)
     *q = 0;
     q = site;
 
-    if (uleq (LocalName (), site))
-	return LocalName ();
+    if (uleq (LocalName(), site))
+	return LocalName();
 
-#ifdef BSD41A
-    if (rhost (&q) != NOTOK) {
-	strcpy (buffer, q);
-	free (q);
-	return buffer;
-    }
-#endif	/* BSD41A */
-
-#if defined(BSD42) || defined(SOCKETS)
 #ifndef	BIND
     sethostent (1);
 #endif
+
     if ((hp = gethostbyname (q))) {
 	strcpy (buffer, hp->h_name);
 	return buffer;
     }
-#endif	/* BSD42 or SOCKETS */
-
     if (hosts.h_name || init_hs ())
 	for (h = hosts.h_next; h; h = h->h_next)
 	    if (uleq (h->h_name, q))
@@ -104,7 +88,7 @@ init_hs (void)
 	return 0;
 
     h = &hosts;
-    while (fgets (buffer, sizeof buffer, fp) != NULL) {
+    while (fgets (buffer, sizeof(buffer), fp) != NULL) {
 	if ((cp = strchr(buffer, '#')))
 	    *cp = 0;
 	if ((cp = strchr(buffer, '\n')))
@@ -136,7 +120,7 @@ init_hs (void)
 
 	*q = 0;
 
-	h->h_next = (struct host *) calloc (1, sizeof *h);
+	h->h_next = (struct host *) calloc (1, sizeof(*h));
 	h = h->h_next;
 	h->h_name = getcpy (dp);
 	r = h->h_aliases =
