@@ -15,7 +15,7 @@ m_replace (char *key, char *value)
 
     m_getdefs ();
     if (!m_defs) {
-	np = m_defs = (struct node *) malloc (sizeof *np);
+	np = m_defs = (struct node *) malloc (sizeof(*np));
 	if (!np)
 	    adios (NULL, "unable to allocate profile storage");
 
