@@ -11,6 +11,7 @@
 # include <h/mh.h>
 # include <h/dropsbr.h>
 # include <zotnet/mts/mts.h>
+# include <zotnet/tws/tws.h>
 #else
 # include "dropsbr.h"
 # include "strings.h"
@@ -28,11 +29,6 @@
 # define ntohl(n) (n)
 #endif
 
-#define	MMDF 1
-#define	UUCP 2
-
-static int mbx_style = MMDF;
-
 extern int errno;
 
 /*
@@ -44,26 +40,7 @@ static int map_open (char *, int *, int);
 
 
 int
-mbx_mmdf(void)
-{
-    int style = mbx_style;
-
-    mbx_style = MMDF;
-    return style;
-}
-
-int
-mbx_uucp(void)
-{
-    int style = mbx_style;
-
-    mbx_style = UUCP;
-    return style;
-}
-
-
-int
-mbx_open (char *file, uid_t uid, gid_t gid, mode_t mode)
+mbx_open (char *file, int mbx_style, uid_t uid, gid_t gid, mode_t mode)
 {
     int clear, fd;
 
@@ -72,7 +49,7 @@ mbx_open (char *file, uid_t uid, gid_t gid, mode_t mode)
 
     if (!clear)
 	switch (mbx_style) {
-	    case MMDF: 
+	    case MMDF_FORMAT: 
 	    default: 
 		if (mbx_chk (fd) == NOTOK) {
 		    close (fd);
@@ -80,7 +57,7 @@ mbx_open (char *file, uid_t uid, gid_t gid, mode_t mode)
 		}
 		break;
 
-	    case UUCP: 
+	    case MBOX_FORMAT: 
 		if (lseek (fd, (off_t) 0, SEEK_END) == (off_t) NOTOK) {
 		    close (fd);
 		    return NOTOK;
@@ -108,11 +85,11 @@ mbx_Xopen (char *file, uid_t uid, gid_t gid, mode_t mode, int *clear)
 		    (*clear)++;
 		    break;
 
-#if defined(FCNTL) || defined(LOCKF)
+#if defined(FCNTL_LOCKING) || defined(LOCKF_LOCKING)
 		case EACCES:
 		case EAGAIN:
 #endif
-#ifdef FLOCK
+#ifdef FLOCK_LOCKING
 		case EWOULDBLOCK:
 #endif
 		case ETXTBSY: 
@@ -145,7 +122,6 @@ mbx_create (char *file, uid_t uid, gid_t gid, mode_t mode)
     close (fd);
     chown (file, uid, gid);
     chmod (file, mode);
-
     return OK;
 }
 
@@ -181,7 +157,7 @@ mbx_read (FILE *fp, long pos, struct drop **drops, int noisy)
     char buffer[BUFSIZ];
     register struct drop *cp, *dp, *ep, *pp;
 
-    pp = (struct drop *) calloc ((size_t) (len = MAXFOLDER), sizeof *dp);
+    pp = (struct drop *) calloc ((size_t) (len = MAXFOLDER), sizeof(*dp));
     if (pp == NULL) {
 	if (noisy)
 	    admonish (NULL, "unable to allocate drop storage");
@@ -289,20 +265,20 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
 
 
 int
-mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
+mbx_copy (char *mailbox, int mbx_style, int md, int fd,
+          int mapping, char *text, int noisy)
 {
-    register int i, j, size;
+    int i, j, size;
     off_t start, stop;
     long pos;
-    register char *cp;
-    char buffer[BUFSIZ];
-    register FILE *fp;
+    char *cp, buffer[BUFSIZ];
+    FILE *fp;
 
     pos = (long) lseek (md, (off_t) 0, SEEK_CUR);
     size = 0;
 
     switch (mbx_style) {
-	case MMDF: 
+	case MMDF_FORMAT: 
 	default: 
 	    j = strlen (mmdlm1);
 	    if (write (md, mmdlm1, j) != j)
@@ -318,7 +294,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 			size++;
 	    }
 		    
-	    while ((i = read (fd, buffer, sizeof buffer)) > 0) {
+	    while ((i = read (fd, buffer, sizeof(buffer))) > 0) {
 		for (j = 0;
 			(j = stringdex (mmdlm1, buffer)) >= 0;
 			buffer[j]++)
@@ -340,11 +316,11 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 	    if (write (md, mmdlm2, j) != j)
 		return NOTOK;
 	    if (mapping)
-		map_write (mailbox, md, 0, (long)0, start, stop, pos, size, noisy);
+		map_write (mailbox, md, 0, (long) 0, start, stop, pos, size, noisy);
 
 	    return (i != NOTOK ? OK : NOTOK);
 
-	case UUCP: 		/* I hate this... */
+	case MBOX_FORMAT:
 	    if ((j = dup (fd)) == NOTOK)
 		return NOTOK;
 	    if ((fp = fdopen (j, "r")) == NULL) {
@@ -353,6 +329,7 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 	    }
 	    start = lseek (md, (off_t) 0, SEEK_CUR);
 
+	    /* If text is given, we add it to top of message */
 	    if (text) {
 		i = strlen (text);
 		if (write (md, text, i) != i)
@@ -362,7 +339,29 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 			size++;
 	    }
 		    
-	    for (j = 0; fgets (buffer, sizeof buffer, fp) != NULL; j++) {
+	    for (j = 0; fgets (buffer, sizeof(buffer), fp) != NULL; j++) {
+
+		/*
+		 * Change the "Return-Path:" field (if in first line)
+		 * back to "From ".  We should probably add a check for
+		 * the "From " line, and build one if necessary.
+		 */
+		if (j == 0 && !text && strncmp (buffer, "Return-Path:", 12) == 0) {
+		    char tmpbuffer[BUFSIZ];
+		    char *tp, *ep, *fp;
+
+		    strcpy(tmpbuffer, buffer);
+		    ep = tmpbuffer + 13;
+		    if (!(fp = strchr(ep + 1, ' ')))
+			fp = strchr(ep + 1, '\n');
+		    tp = dctime(dtwstime());
+		    sprintf (buffer, "From %.*s  %s", fp - ep, ep, tp);
+		}
+
+		/*
+		 * If this is not first line, and begins with
+		 * "From ", then prepend line with ">".
+		 */
 		if (j != 0 && strncmp (buffer, "From ", 5) == 0) {
 		    write (md, ">", 1);
 		    size++;
@@ -381,11 +380,12 @@ mbx_copy (char *mailbox, int md, int fd, int mapping, char *text, int noisy)
 		fclose (fp);
 		return NOTOK;
 	    }
-	    if (mapping) size += 2;
+	    if (mapping)
+		size += 2;
 
 	    fclose (fp);
 	    lseek (fd, (off_t) 0, SEEK_END);
-	    stop = lseek (md, (off_t)0, SEEK_CUR);
+	    stop = lseek (md, (off_t) 0, SEEK_CUR);
 	    if (mapping)
 		map_write (mailbox, md, 0, (long)0, start, stop, pos, size, noisy);
 
@@ -413,7 +413,6 @@ mbx_size (int md, off_t start, off_t stop)
 	    i++;
 
     fclose (fp);
-
     return i;
 }
 
@@ -422,15 +421,14 @@ int
 mbx_close (char *mailbox, int md)
 {
     lkclose (md, mailbox);
-
     return OK;
 }
 
 
-/* This function is performed implicitly by getbbent.c:
-
-		bb->bb_map = map_name (bb->bb_file);
-*/
+/*
+ * This function is performed implicitly by getbbent.c:
+ *     bb->bb_map = map_name (bb->bb_file);
+ */
 
 char *
 map_name (char *file)
@@ -477,9 +475,8 @@ map_read (char *file, long pos, struct drop **drops, int noisy)
     if ((i = read (md, (char *) (dp + 1), msgp * sizeof *dp)) < sizeof *dp) {
 	i = 0;
 	free ((char *) dp);
-    }
-    else {
-#ifdef	NTOHLSWAP
+    } else {
+#ifdef NTOHLSWAP
 	register struct drop *tdp;
 	int j;
 
@@ -613,18 +610,18 @@ map_chk (char *file, int fd, struct drop *dp, long pos, int noisy)
     register struct drop *dl;
 
     if (read (fd, (char *) &tmpd, sizeof *dp) != sizeof *dp) {
-#ifdef	notdef
+#ifdef notdef
 	admonish (NULL, "%s: missing or partial index", file);
-#endif	/* notdef */
+#endif /* notdef */
 	return NOTOK;
     }
 #ifndef	NTOHLSWAP
     *dp = tmpd;		/* if ntohl(n)=(n), can use struct assign */
 #else
-    dp->d_id = ntohl(tmpd.d_id);
-    dp->d_size = ntohl(tmpd.d_size);
+    dp->d_id    = ntohl(tmpd.d_id);
+    dp->d_size  = ntohl(tmpd.d_size);
     dp->d_start = ntohl(tmpd.d_start);
-    dp->d_stop = ntohl(tmpd.d_stop);
+    dp->d_stop  = ntohl(tmpd.d_stop);
 #endif
     
     if (dp->d_size != DRVRSN) {
