@@ -114,7 +114,7 @@ static struct msgs *mp = NULL;		/* used a lot */
  * static prototypes
  */
 static int build_form (char *, char *, int, int);
-static copy_draft (int, char *, char *, int, int, int);
+static void copy_draft (int, char *, char *, int, int, int);
 static void mhl_draft(int, char *, int, int, char *, char *, int);
 
 
@@ -148,7 +148,7 @@ main (int argc, char **argv)
     copyip (argv + 1, ap);
     argp = arguments;
 
-    while (cp = *argp++) {
+    while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
@@ -494,7 +494,7 @@ mhl_draft  (int out, char *digest, int volume, int issue,
 }
 
 
-static
+static void
 copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 {
     int fd,i, msgcnt, msgnum;
@@ -503,7 +503,8 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 
 #ifdef MIME
     if (mime) {
-	sprintf (buffer, "#forw [] +%s", mp->foldpath);
+	sprintf (buffer, "#forw [forwarded message%s] +%s",
+		 mp->numsel == 1 ? "" : "s", mp->foldpath);
 	write (out, buffer, strlen (buffer));
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (mp->msgstats[msgnum] & SELECTED) {
