@@ -237,7 +237,7 @@ static char delim3[] =		/* from forw.c */
     "\n----------------------------------------------------------------------\n\n";
 static char delim4[] = "\n------------------------------\n\n";
 
-static FP (*mhl_action) () = (FP (*) ()) 0;
+static FILE *(*mhl_action) () = (FILE *(*) ()) 0;
 
 
 /*
@@ -276,7 +276,7 @@ static void mhldone (int);
 static void m_popen (char *);
 
 int mhl (int, char **);
-int mhlsbr (int, char **, FP (*)());
+int mhlsbr (int, char **, FILE *(*)());
 void m_pclose (void);
 
 void clear_screen (void);             /* from termsbr.c */
@@ -1622,7 +1622,7 @@ doface (struct mcomp *c1)
 
 
 int
-mhlsbr (int argc, char **argv, FP (*action)())
+mhlsbr (int argc, char **argv, FILE *(*action)())
 {
     SIGNAL_HANDLER istat, pstat, qstat;
     char *cp;
