@@ -18,11 +18,14 @@
 #include <zotnet/tws/tws.h>
 #include <zotnet/mts/mts.h>
 
-#ifdef SYS5
-# include <termio.h>
-# include <sys/ioctl.h>
+#ifdef HAVE_TERMIOS_H
+# include <termios.h>
 #else
-# include <sgtty.h>
+# ifdef HAVE_TERMIO_H
+#  include <termio.h>
+# else
+#  include <sgtty.h>
+# endif
 #endif
 
 #include <pwd.h>
@@ -90,7 +93,9 @@ static int numfds = 0;			/* number of files cached              */
 static int maxfds = 0;			/* number of files cached to be cached */
 static time_t mtime = (time_t) 0;	/* mtime of file                       */
 
-				/* VMH */
+/*
+ * VMH
+ */
 #define	ALARM	((unsigned int) 10)
 #define	ttyN(c)	ttyNaux ((c), NULL)
 
@@ -118,7 +123,7 @@ static jmp_buf peerenv;
 #ifdef BPOP
 int pmsh = 0;			/* BPOP enabled */
 extern char response[];
-#endif	/* BPOP */
+#endif /* BPOP */
 
 /*
  * PARENT
@@ -237,7 +242,7 @@ main (int argc, char **argv)
     char *cp, *file = NULL, *folder = NULL;
     char **ap, **argp, buf[80];
     char *arguments[MAXARGS];
-#ifdef	BPOP
+#ifdef BPOP
     int	pmsh1 = 0, pmsh2 = 0;
 #endif
 
@@ -323,18 +328,18 @@ main (int argc, char **argv)
 		case PREADSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-#ifdef	BPOP
+#ifdef BPOP
 		    if ((pmsh1 = atoi (cp)) < 1)
 			adios (NULL, "bad argument %s %s", argp[-2], cp);
-#endif	/* BPOP */
+#endif /* BPOP */
 		    continue;
 		case PWRITSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-#ifdef	BPOP
+#ifdef BPOP
 		    if ((pmsh2 = atoi (cp)) < 1)
 			adios (NULL, "bad argument %s %s", argp[-2], cp);
-#endif	/* BPOP */
+#endif /* BPOP */
 		    continue;
 
 		case TCURSW:
@@ -365,7 +370,7 @@ main (int argc, char **argv)
 #ifdef FIOCLEX
     if (pfd > 1)
 	ioctl (pfd, FIOCLEX, NULL);
-#endif	/* FIOCLEX */
+#endif /* FIOCLEX */
 
 #ifdef BSD42
     should_intr = 0;
@@ -380,24 +385,24 @@ main (int argc, char **argv)
 	pINI ();
 	SIGNAL (SIGINT, SIG_IGN);
 	SIGNAL (SIGQUIT, SIG_IGN);
-#ifdef	SIGTSTP
+#ifdef SIGTSTP
 	tstat = SIGNAL (SIGTSTP, SIG_IGN);
-#endif	/* SIGTSTP */
+#endif /* SIGTSTP */
     }
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh = pmsh1 && pmsh2) {
 	cp = getenv ("MHPOPDEBUG");
-#ifdef	NNTP
+#ifdef NNTP
 	if (pop_set (pmsh1, pmsh2, cp && *cp, myname) == NOTOK)
-#else	/* NNTP */
+#else /* NNTP */
 	if (pop_set (pmsh1, pmsh2, cp && *cp) == NOTOK)
-#endif	/* NNTP */
+#endif /* NNTP */
 	    padios (NULL, "%s", response);
 	if (folder)
 	    file = folder, folder = NULL;
     }
-#endif	/* BPOP */
+#endif /* BPOP */
 
     if (folder)
 	fsetup (folder);
@@ -611,7 +616,7 @@ msh (int scansw)
 		break;
 
 	    case MHNCMD:
-#ifdef	MIME
+#ifdef MIME
 		if (!vmh || ttyN (cmdp) != NOTOK)
 		    mhncmd (vec);
 #endif
@@ -725,7 +730,7 @@ setup (char *file)
     char tmpfil[BUFSIZ];
 #endif
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh) {
 	strcpy (tmpfil, m_tmpfil (invo_name));
 	if ((fp = fopen (tmpfil, "w+")) == NULL)
@@ -733,12 +738,12 @@ setup (char *file)
 	unlink (tmpfil);
     }
     else
-#endif	/* BPOP */
+#endif /* BPOP */
     if ((fp = fopen (file, "r")) == NULL)
 	padios (file, "unable to read");
-#ifdef	FIOCLEX
+#ifdef FIOCLEX
     ioctl (fileno (fp), FIOCLEX, NULL);
-#endif	/* FIOCLEX */
+#endif /* FIOCLEX */
     if (fstat (fileno (fp), &st) != NOTOK) {
 	mode = (int) (st.st_mode & 0777), mtime = st.st_mtime;
 	msgp = read_map (file, (long) st.st_size);
@@ -762,21 +767,21 @@ setup (char *file)
 
     mp->foldpath = getcpy (myname ? myname : file);
     mp->msgflags = 0;
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh)
 	mp->msgflags |= READONLY;
     else {
-#endif	/* BPOP */
+#endif /* BPOP */
 	stat (file, &st);
 	if (st.st_uid != getuid () || access (file, W_OK) == NOTOK)
 	    mp->msgflags |= READONLY;
-#ifdef	BPOP
+#ifdef BPOP
     }
 #endif	/* BPOP */
     mp->lowoff = 1;
     mp->hghoff = mp->hghmsg + 1;
 
-#ifdef	MTR
+#ifdef MTR
     mp->msgstats = (short *)
 		calloc ((size_t) 1, MHSIZEX (mp, mp->lowmsg, mp->hghmsg));
     if (mp->msgstats == NULL)
@@ -784,20 +789,20 @@ setup (char *file)
     mp->msgstats = (mp->msgbase = mp->msgstats) - mp->lowoff;
     if (mp->msgstats < (short *)0)
 	padios (NULL, "setup() botch -- you lose big");
-#endif	/* MTR */
-#ifdef	BPOP
+#endif /* MTR */
+#ifdef BPOP
     if (pmsh) {
 #ifndef	NNTP
 	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
 	    Msgs[i].m_top = i;
 	    mp->msgstats[i] = EXISTS | VIRTUAL;
 	}
-#else	/* NNTP */
+#else /* NNTP */
 	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
 	    if (Msgs[i].m_top)			/* set in read_pop() */
 		mp->msgstats[i] = EXISTS | VIRTUAL;
 	}
-#endif	/* NNTP */
+#endif /* NNTP */
     }
     else
 #endif	/* BPOP */
@@ -823,10 +828,10 @@ read_map (char *file, long size)
     register struct drop *dp, *mp;
     struct drop *rp;
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh)
 	return read_pop ();
-#endif	/* BPOP */
+#endif /* BPOP */
 
     if ((i = map_read (file, size, &rp, 1)) == 0)
 	return 0;
@@ -855,10 +860,10 @@ read_file (long pos, int msgp)
     register struct drop *dp, *mp;
     struct drop *rp;
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh)
 	return (msgp - 1);
-#endif	/* BPOP */
+#endif /* BPOP */
 
     if ((i = mbx_read (fp, pos, &rp, 1)) <= 0)
 	return (msgp - 1);
@@ -879,8 +884,8 @@ read_file (long pos, int msgp)
 }
 
 
-#ifdef	BPOP
-#ifdef	NNTP
+#ifdef BPOP
+#ifdef NNTP
 static int pop_base = 0;
 
 static int
@@ -892,7 +897,7 @@ pop_statmsg (char *s)
     Msgs[n].m_top = Msgs[n].m_bboard_id = i;
 }
 
-#endif	/* NNTP */
+#endif /* NNTP */
 
 static int
 read_pop (void)
@@ -904,10 +909,10 @@ read_pop (void)
 
     m_gMsgs (nmsgs);
 
-#ifdef	NNTP	/* this makes read_pop() do some real work... */
+#ifdef NNTP	/* this makes read_pop() do some real work... */
     pop_base = nbytes - 1; 	/* nmsgs=last-first+1, nbytes=first */
     pop_exists (pop_statmsg);
-#endif	/* NNTP */
+#endif /* NNTP */
     return nmsgs;
 }
 
@@ -917,7 +922,7 @@ pop_action (char *s)
 {
     fprintf (yp, "%s\n", s);
 }
-#endif	/* BPOP */
+#endif /* BPOP */
 
 
 static void
@@ -984,7 +989,7 @@ msh_ready (int msgnum, int full)
 	return yp;
     }
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh && (mp->msgstats[msgnum] & VIRTUAL)) {
 	if (Msgs[msgnum].m_top == 0)
 	    padios (NULL, "msh_ready (%d, %d) botch", msgnum, full);
@@ -1026,7 +1031,7 @@ msh_ready (int msgnum, int full)
 
 	mp->msgstats[msgnum] &= ~VIRTUAL;
     }
-#endif	/* BPOP */
+#endif /* BPOP */
 
     m_eomsbr ((int (*)()) 0);	/* XXX */
     fseek (fp, Msgs[msgnum].m_start, 0);
@@ -1040,10 +1045,10 @@ check_folder (int scansw)
     int flags, i, low, hgh, msgp;
     struct stat st;
 
-#ifdef	BPOP
+#ifdef BPOP
     if (pmsh)
 	return 0;
-#endif	/* BPOP */
+#endif /* BPOP */
 
     if (fmsh) {
 	if (stat (mp->foldpath, &st) == NOTOK)
