@@ -246,10 +246,8 @@ main (int argc, char **argv)
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (mp->msgstats[msgnum] & SELECTED)
 		printf ("%s\n", m_name (msgnum));
-    }
-    else
-	printf ("%d hit%s\n", mp->numsel,
-		mp->numsel == 1 ? "" : "s");
+    } else
+	printf ("%d hit%s\n", mp->numsel, mp->numsel == 1 ? "" : "s");
 
     m_replace (pfolder, folder);
     m_sync (mp);
