@@ -214,23 +214,23 @@ static struct headers RHeaders[] = {
 static short fccind = 0;	/* index into fccfold[] */
 static short outputlinelen = OUTPUTLINELEN;
 
-static int  pfd = NOTOK;	/* fd to write annotation list to */
-static uid_t myuid= -1;		/* my user id */
-static gid_t mygid= -1;		/* my group id */
-static int  recipients = 0;	/* how many people will get a copy */
-static int  unkadr = 0;		/* how many of those were unknown */
-static int  badadr = 0;		/* number of bad addrs */
-static int  badmsg = 0;		/* message has bad semantics */
-static int  verbose = 0;	/* spell it out */
-static int  format = 1;		/* format addresses */
-static int  mime = 0;		/* use MIME-style encapsulations */
-static int  msgid = 0;		/* add msgid */
-static int  debug = 0;		/* debugging post */
-static int  watch = 0;		/* watch the delivery process */
-static int  whomsw = 0;		/* we are whom not post */
-static int  checksw = 0;	/* whom -check */
-static int  linepos=0;		/* putadr()'s position on the line */
-static int  nameoutput=0;	/* putadr() has output header name */
+static int pfd = NOTOK;		/* fd to write annotation list to  */
+static uid_t myuid= -1;		/* my user id                      */
+static gid_t mygid= -1;		/* my group id                     */
+static int recipients = 0;	/* how many people will get a copy */
+static int unkadr = 0;		/* how many of those were unknown  */
+static int badadr = 0;		/* number of bad addrs             */
+static int badmsg = 0;		/* message has bad semantics       */
+static int verbose = 0;		/* spell it out                    */
+static int format = 1;		/* format addresses                */
+static int mime = 0;		/* use MIME-style encapsulations   */
+static int msgid = 0;		/* add msgid                       */
+static int debug = 0;		/* debugging post                  */
+static int watch = 0;		/* watch the delivery process      */
+static int whomsw = 0;		/* we are whom not post            */
+static int checksw = 0;		/* whom -check                     */
+static int linepos=0;		/* putadr()'s position on the line */
+static int nameoutput=0;	/* putadr() has output header name */
 
 static unsigned msgflags = 0;	/* what we've seen */
 
@@ -238,29 +238,29 @@ static unsigned msgflags = 0;	/* what we've seen */
 #define	RESENT 1
 static int msgstate = NORMAL;
 
-static long tclock = 0L;		/* the time we started (more or less) */
+static time_t tclock = 0;	/* the time we started (more or less) */
 
 static SIGNAL_HANDLER hstat, istat, qstat, tstat;
 
 static char tmpfil[BUFSIZ];
 static char bccfil[BUFSIZ];
 
-static char from[BUFSIZ];	/* my network address */
-static char signature[BUFSIZ];	/* my signature */
-static char *filter = NULL;	/* the filter for BCC'ing */
+static char from[BUFSIZ];	/* my network address            */
+static char signature[BUFSIZ];	/* my signature                  */
+static char *filter = NULL;	/* the filter for BCC'ing        */
 static char *subject = NULL;	/* the subject field for BCC'ing */
-static char *fccfold[FCCS];	/* foldernames for FCC'ing */
+static char *fccfold[FCCS];	/* foldernames for FCC'ing       */
 
 static struct headers  *hdrtab;	/* table for the message we're doing */
 
-static struct mailname localaddrs={NULL};	/* local addrs */
-static struct mailname netaddrs={NULL};		/* network addrs */
-static struct mailname uuaddrs={NULL};		/* uucp addrs */
+static struct mailname localaddrs={NULL};	/* local addrs     */
+static struct mailname netaddrs={NULL};		/* network addrs   */
+static struct mailname uuaddrs={NULL};		/* uucp addrs      */
 static struct mailname tmpaddrs={NULL};		/* temporary queue */
 
 #ifdef MMDFMTS
-static char *submitmode = "m";	/* deliver to mailbox only */
-static char submitopts[6] = "vl";/* initial options for submit */
+static char *submitmode = "m";		/* deliver to mailbox only    */
+static char submitopts[6] = "vl";	/* initial options for submit */
 #endif /* MMDFMTS */
 
 #ifdef MHMTS
@@ -401,10 +401,10 @@ main (int argc, char **argv)
 		case ALIASW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-#ifdef	MHMTS
+#ifdef MHMTS
 		    if (access (etcpath (cp), R_OK) == NOTOK)
 			adios (cp, "unable to read");
-#endif	/* MHMTS */
+#endif /* MHMTS */
 		    if ((state = alias (cp)) != AK_OK)
 			adios (NULL, "aliasing error in %s - %s",
 				cp, akerror (state));
@@ -442,7 +442,7 @@ main (int argc, char **argv)
 		    continue;
 
 		case MIMESW:
-#ifdef	MIME
+#ifdef MIME
 		    mime++;
 		    filter = 0;
 #endif
@@ -497,7 +497,7 @@ main (int argc, char **argv)
 			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 		case MAILSW:
 		    submitmode = "m";
 		    continue;
@@ -508,14 +508,14 @@ main (int argc, char **argv)
 		case SENDSW:
 		    submitmode = "y";
 		    continue;
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS */
 
 #ifndef	MHMTS
 		case DLVRSW:
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
-#else	/* MHMTS */
+#else /* MHMTS */
 		case MAILSW:
 		case SAMLSW:
 		case SOMLSW:
@@ -525,7 +525,7 @@ main (int argc, char **argv)
 		    if (!(deliver = *argp++) || *deliver == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
-#endif	/* MHMTS */
+#endif /* MHMTS */
 
 #ifndef	SENDMTS
 		case CLIESW:
@@ -536,7 +536,7 @@ main (int argc, char **argv)
 
 		case SNOOPSW:
 		    continue;
-#else	/* SENDMTS */
+#else /* SENDMTS */
 		case MAILSW:
 		    smtpmode = S_MAIL;
 		    continue;
@@ -560,7 +560,7 @@ main (int argc, char **argv)
 		case SNOOPSW:
 		    snoop++;
 		    continue;
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
 		case FILLSW:
 		    if (!(fill_in = *argp++) || *fill_in == '-')
@@ -592,10 +592,10 @@ main (int argc, char **argv)
     if (outputlinelen < 10)
 	adios (NULL, "impossible width %d", outputlinelen);
 
-#ifdef	MHMTS
+#ifdef MHMTS
     if (access (msg, R_OK) == NOTOK)
 	adios (msg, "unable to read");
-#endif	/* MHMTS */
+#endif /* MHMTS */
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
 
@@ -603,16 +603,16 @@ main (int argc, char **argv)
     if (debug) {
 	verbose++;
 	discard (out = stdout);	/* XXX: reference discard() to help loader */
-#ifdef	MHMTS
+#ifdef MHMTS
 	if (deliver) {
 	    strcpy (tmpfil, msg);
 	    putfmt ("To", deliver, out);
 	    goto daemon;
 	}
-#endif	/* MHMTS */
+#endif /* MHMTS */
     }
     else
-#ifdef	MHMTS
+#ifdef MHMTS
     if (deliver) {
 	if ((out = fopen ("/dev/null", "r")) == NULL)
 	    adios ("/dev/null", "unable to write");
@@ -621,7 +621,7 @@ main (int argc, char **argv)
 	goto daemon;
     }
     else
-#endif	/* MHMTS */
+#endif /* MHMTS */
 	if (whomsw) {
 	    if ((out = fopen (fill_in ? fill_in : "/dev/null", "w")) == NULL)
 		adios ("/dev/null", "unable to open");
@@ -633,7 +633,7 @@ main (int argc, char **argv)
 		if ((out = fopen (tmpfil, "w")) == NULL)
 		    adios (tmpfil, "unable to create");
 	    }
-#ifdef	MHMTS
+#ifdef MHMTS
 	    chown (tmpfil, myuid, mygid);
 #endif	/* MHMTS */
 	    chmod (tmpfil, 0600);
@@ -687,9 +687,9 @@ main (int argc, char **argv)
     }
 
 
-#ifdef	MHMTS
+#ifdef MHMTS
 daemon: ;
-#endif	/* MHMTS */
+#endif /* MHMTS */
     if (pfd != NOTOK)
 	anno ();
     fclose (in);
@@ -700,24 +700,24 @@ daemon: ;
     else
 	fclose (out);
 
-#ifdef	TMA
+#ifdef TMA
     if (encryptsw)
 	tmastart (tmasnoop);
-#endif	/* TMA */
+#endif /* TMA */
     if (whomsw) {
 	if (!fill_up)
 	    verify_all_addresses (1);
 	done (0);
     }
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     strcat (submitopts, submitmode);
     if (watch)
 	strcat (submitopts, "nw");
-#endif	/* MMDFMTS */
-#ifdef	MHMTS
+#endif /* MMDFMTS */
+#ifdef MHMTS
     verify_all_addresses (0);
-#endif	/* MHMTS */
+#endif /* MHMTS */
     if (encryptsw)
 	verify_all_addresses (verbose);
     if (msgflags & MINV) {
@@ -726,7 +726,7 @@ daemon: ;
 #ifndef	MHMTS
 	    if (!encryptsw)
 		verify_all_addresses (verbose);
-#endif	/* not MHMTS */
+#endif /* not MHMTS */
 	    post (tmpfil, 0, verbose);
 	}
 	post (bccfil, 1, verbose);
@@ -734,16 +734,16 @@ daemon: ;
     }
     else
 	post (tmpfil, 0, isatty (1));
-#ifdef	TMA
+#ifdef TMA
     if (encryptsw)
 	tmastop ();
-#endif	/* TMA */
+#endif /* TMA */
 
     p_refile (tmpfil);
 
-#ifdef	MHMTS
+#ifdef MHMTS
     if (!deliver)
-#endif	/* MHMTS */
+#endif /* MHMTS */
 	unlink (tmpfil);
 
     if (verbose)
@@ -869,9 +869,9 @@ putfmt (char *name, char *str, FILE *out)
 			putgrp (namep, mp->m_gname, out, hdr->flags);
 		if (mp->m_ingrp)
 		    grp++;
-#ifdef	MHMTS
+#ifdef MHMTS
 		mp->m_aka = getcpy (np->m_mbox);
-#endif	/* MHMTS */
+#endif /* MHMTS */
 		if (putadr (namep, qp, mp, out, hdr->flags))
 		    msgflags |= (hdr->set & (MVIS | MINV));
 		else
@@ -928,13 +928,13 @@ start_headers (void)
     for (cp = myhost; *cp; cp++)
 	*cp = uptolow (*cp);
 
-#ifdef	MHMTS
+#ifdef MHMTS
     if (deliver) {
 	if (geteuid () == 0 && myuid != 0 && myuid != 1 && mygid != 1)
 	    adios (NULL, "-deliver unknown");
 	strcpy (signature, from);
     }
-#endif	/* MHMTS */
+#endif /* MHMTS */
 
     if ((cp = getfullname ()) && *cp) {
 	strcpy (sigbuf, cp);
@@ -987,9 +987,9 @@ finish_headers (FILE *out)
 	    if (whomsw && !fill_up)
 		break;
 
-#ifdef	MMDFI			/* sigh */
+#ifdef MMDFI			/* sigh */
 	    fprintf (out, "Sender: %s\n", from);
-#endif	/* MMDFI */
+#endif /* MMDFI */
 
 	    fprintf (out, "Resent-Date: %s\n", dtime (&tclock));
 	    if (msgid)
@@ -1356,13 +1356,13 @@ verify_all_addresses (int talk)
 {
 #ifndef	MHMTS
     int retval;
-#endif	/* not MHMTS */
-#ifdef	MMDFMTS
-#ifdef	RP_NS
-    int	    len;
+#endif /* not MHMTS */
+#ifdef MMDFMTS
+#ifdef RP_NS
+    int	len;
     struct rp_bufstruct reply;
-#endif	/* RP_NS */
-#endif	/* MMDFMTS */
+#endif /* RP_NS */
+#endif /* MMDFMTS */
     register struct mailname *lp;
 
 #ifndef	MHMTS
@@ -1376,13 +1376,13 @@ verify_all_addresses (int talk)
 		|| rp_isbad (retval = mm_winit (NULL, submitopts, from)))
 	    die (NULL, "problem initializing MMDF system [%s]",
 		    rp_valstr (retval));
-#ifdef	RP_NS
+#ifdef RP_NS
 	if (rp_isbad (retval = mm_rrply (&reply, &len)))
 	    die (NULL, "problem with sender address [%s]",
 		    rp_valstr (retval));
-#endif	/* RP_NS */
+#endif /* RP_NS */
     }
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS */
 #ifdef SENDMTS
     if (!whomsw || checksw)
 	if (rp_isbad (retval = sm_init (clientsw, serversw, 0, 0, snoop, 0, 0))
@@ -1396,7 +1396,7 @@ verify_all_addresses (int talk)
 #ifndef	BERK
     if (talk && localaddrs.m_next)
 	printf ("  -- Local Recipients --\n");
-#endif	/* BERK */
+#endif /* BERK */
     for (lp = localaddrs.m_next; lp; lp = lp->m_next)
 	do_an_address (lp, talk, encryptsw);
 
@@ -1418,19 +1418,19 @@ verify_all_addresses (int talk)
     if (talk && !whomsw)
 	printf (" -- Address Verification Successful --\n");
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (!whomsw || checksw)
 	mm_end (NOTOK);
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* MMDFMTS */
+#ifdef SENDMTS
     if (!whomsw || checksw)
 	sm_end (DONE);
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
     fflush (stdout);
 
 #ifndef	MHMTS
     sigoff ();
-#endif	/* not MHMTS */
+#endif /* not MHMTS */
 }
 
 
@@ -1461,15 +1461,15 @@ post (char *file, int bccque, int talk)
     int fd, onex = !(msgflags & MINV) || bccque;
 #ifndef	MHMTS
     int	retval;
-#ifdef	MMDFMTS
-#ifdef	RP_NS
+#ifdef MMDFMTS
+#ifdef RP_NS
     int	len;
     struct rp_bufstruct reply;
-#endif	/* RP_NS */
-#endif	/* MMDFMTS */
-#else	/* MHMTS */
-    int	    ud;
-#endif	/* MHMTS */
+#endif /* RP_NS */
+#endif /* MMDFMTS */
+#else /* MHMTS */
+    int	ud;
+#endif /* MHMTS */
 
     if (verbose)
 	if (msgflags & MINV)
@@ -1480,52 +1480,52 @@ post (char *file, int bccque, int talk)
 
     sigon ();
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (rp_isbad (retval = mm_init ())
 	    || rp_isbad (retval = mm_sbinit ())
 	    || rp_isbad (retval = mm_winit (NULL, submitopts, from)))
 	die (NULL, "problem initializing MMDF system [%s]",
 		rp_valstr (retval));
-#ifdef	RP_NS
+#ifdef RP_NS
 	if (rp_isbad (retval = mm_rrply (&reply, &len)))
 	    die (NULL, "problem with sender address [%s]",
 		    rp_valstr (retval));
-#endif	/* RP_NS */
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* RP_NS */
+#endif /* MMDFMTS */
+#ifdef SENDMTS
     if (rp_isbad (retval = sm_init (clientsw, serversw, watch, verbose, snoop,
 				    onex, queued))
 	    || rp_isbad (retval = sm_winit (smtpmode, from)))
 	die (NULL, "problem initializing server; %s", rp_string (retval));
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
 #ifndef	MHMTS
     do_addresses (bccque, talk && verbose);
     if ((fd = open (file, 0)) == NOTOK)
 	die (file, "unable to re-open");
     do_text (file, fd);
-#else	/* MHMTS */
+#else /* MHMTS */
     if ((fd = open (file, 0)) == NULL)
 	adios (file, "unable to re-open");
-#ifdef	MF
+#ifdef MF
     ud = UucpChan () && uuaddrs.m_next ? make_uucp_file (fd) : NOTOK;
-#else	/* not MF */
+#else /* not MF */
     ud = NOTOK;
-#endif	/* not MF */
+#endif /* not MF */
     do_addresses (file, fd, ud, bccque, talk && verbose);
     if (ud != NOTOK)
 	close (ud);
-#endif	/* MHMTS */
+#endif /* MHMTS */
     close (fd);
     fflush (stdout);
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     mm_sbend ();
     mm_end (OK);
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS */
 #ifdef	SENDMTS
     sm_end (onex ? OK : DONE);
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     sigoff ();
 
@@ -1565,11 +1565,11 @@ postcipher (char *file, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- Local Recipients --\n");
-#endif	/* BERK */
+#endif /* BERK */
 	    do_a_cipher (lp, talk);
 #ifndef	BERK
 	    state++;
-#endif	/* BERK */
+#endif /* BERK */
 	}
 
     for (state = 0, lp = uuaddrs.m_next; lp; lp = lp->m_next)
@@ -1577,11 +1577,11 @@ postcipher (char *file, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- UUCP Recipients --\n");
-#endif	/* BERK */
+#endif /* BERK */
 	    do_a_cipher (lp, talk);
 #ifndef	BERK
 	    state++;
-#endif	/* BERK */
+#endif /* BERK */
 	}
 
     for (state = 0, lp = netaddrs.m_next; lp; lp = lp->m_next)
@@ -1589,19 +1589,19 @@ postcipher (char *file, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- Network Recipients --\n");
-#endif	/* BERK */
+#endif /* BERK */
 	    do_a_cipher (lp, talk);
 #ifndef	BERK
 	    state++;
-#endif	/* BERK */
+#endif /* BERK */
 	}
 
     if (ciphdone (reason) == NOTOK)
 	admonish (NULL, "%s", reason);
-#ifdef	SENDMTS
+#ifdef SENDMTS
     if (!(msgflags & MINV) || bccque)
 	sm_end (OK);
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     if (verbose)
 	if (msgflags & MINV)
@@ -1619,27 +1619,27 @@ do_a_cipher (struct mailname *lp, int talk)
     int fd, retval;
     register char *mbox, *host;
     char addr[BUFSIZ], reason[BUFSIZ];
-#ifdef	MMDFMTS
-#ifdef	RP_NS
+#ifdef MMDFMTS
+#ifdef RP_NS
     int	    len;
     struct rp_bufstruct reply;
-#endif	/* RP_NS */
-#endif	/* MMDFMTS */
+#endif /* RP_NS */
+#endif /* MMDFMTS */
 
     sigon ();
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (rp_isbad (retval = mm_init ())
 	    || rp_isbad (retval = mm_sbinit ())
 	    || rp_isbad (retval = mm_winit (NULL, submitopts, from)))
 	die (NULL, "problem initializing MMDF system [%s]",
 		rp_valstr (retval));
-#ifdef	RP_NS
+#ifdef RP_NS
 	if (rp_isbad (retval = mm_rrply (&reply, &len)))
 	    die (NULL, "problem with sender address [%s]",
 		    rp_valstr (retval));
-#endif	/* RP_NS */
-#endif	/* MMDFMTS */
+#endif /* RP_NS */
+#endif /* MMDFMTS */
 #ifdef SENDMTS
     if (rp_isbad (retval = sm_init (clientsw, serversw, watch, verbose, snoop,
 				    0, 0))
@@ -1657,14 +1657,14 @@ do_a_cipher (struct mailname *lp, int talk)
 	    break;
 
 	case UUCPHOST: 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
 	    mbox = concat (lp->m_host, "!", lp->m_mbox, NULL);
 	    host = UucpChan ();
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* MMDFMTS */
+#ifdef SENDMTS
 	    mbox = auxformat (lp, 0);
 	    host = NULL;
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 	    sprintf (addr, "%s!%s", lp->m_host, lp->m_mbox);
 	    break;
 
@@ -1676,15 +1676,15 @@ do_a_cipher (struct mailname *lp, int talk)
     }
     chkadr ();			/* XXX */
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (rp_isbad (retval = mm_waend ()))
 	die (NULL, "problem ending addresses [%s]\n",
 		rp_valstr (retval));
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS */
 #ifdef	SENDMTS
     if (rp_isbad (retval = sm_waend ()))
 	die (NULL, "problem ending addresses; %s", rp_string (retval));
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     if ((fd = encipher (mbox, host, reason)) == NOTOK)
 	die (NULL, "%s: %s", addr, reason);
@@ -1692,17 +1692,17 @@ do_a_cipher (struct mailname *lp, int talk)
     close (fd);
     fflush (stdout);
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     mm_sbend ();
     mm_end (OK);
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* MMDFMTS */
+#ifdef SENDMTS
     sm_end (DONE);
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
     sigoff ();
 }
-#endif	/* TMA */
+#endif /* TMA */
 
 
 #ifndef	MHMTS
@@ -1716,7 +1716,7 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
     int retval;
 #ifndef	BERK
     int	state;
-#endif	/* not BERK */
+#endif /* not BERK */
     register struct mailname *lp;
 
 #ifndef	BERK
@@ -1727,15 +1727,15 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- Local Recipients --\n");
-#endif	/* not BERK */
+#endif /* not BERK */
 #ifndef	MHMTS
 	    do_an_address (lp, talk, 0);
-#else	/* MHMTS */
+#else /* MHMTS */
 	    localmail (lp, talk, fd);
-#endif	/* MHMTS */
+#endif /* MHMTS */
 #ifndef	BERK
 	    state++;
-#endif	/* not BERK */
+#endif /* not BERK */
 	}
 
 #ifndef	BERK
@@ -1746,15 +1746,15 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- UUCP Recipients --\n");
-#endif	/* not BERK */
+#endif /* not BERK */
 #ifndef	MHMTS
 	    do_an_address (lp, talk, 0);
-#else	/* MHMTS */
+#else /* MHMTS */
 	    uucpmail (lp, talk, ud != NOTOK ? ud : fd, ud == NOTOK);
-#endif	/* MHMTS */
+#endif /* MHMTS */
 #ifndef	BERK
 	    state++;
-#endif	/* not BERK */
+#endif /* not BERK */
 	}
 
 #ifndef	BERK
@@ -1765,28 +1765,28 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
 #ifndef	BERK
 	    if (talk && !state)
 		printf ("  -- Network Recipients --\n");
-#endif	/* not BERK */
+#endif /* not BERK */
 #ifndef	MHMTS
 	    do_an_address (lp, talk, 0);
 #else /* MHMTS */
 	    netmail (talk, fd, bccque);
-#endif	/* MHMTS */
+#endif /* MHMTS */
 #ifndef	BERK
 	    state++;
-#endif	/* not BERK */
+#endif /* not BERK */
 	}
 
     chkadr ();
 
-#ifdef	MMDFMTS
+#ifdef MMDFMTS
     if (rp_isbad (retval = mm_waend ()))
 	die (NULL, "problem ending addresses [%s]\n",
 		rp_valstr (retval));
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* MMDFMTS */
+#ifdef SENDMTS
     if (rp_isbad (retval = sm_waend ()))
 	die (NULL, "problem ending addresses; %s", rp_string (retval));
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 }
 
 
