@@ -21,10 +21,6 @@
 # endif
 #endif
 
-#ifdef SYS5
-# include <sys/ioctl.h>
-#endif
-
 #define	QUOTE '\\'
 
 #ifndef	CKILL
