@@ -12,19 +12,28 @@
 #include <zotnet/mts/mts.h>
 
 static struct swit switches[] = {
-#define VERSIONSW 0
+#define MBOXSW       0
+    { "mbox", 0 },
+#define MMDFSW       1
+    { "mmdf", 0 },
+#define VERSIONSW    2
     { "version", 0 },
-#define	HELPSW    1
+#define	HELPSW       3
     { "help", 4 },
     { NULL, 0 }
 };
 
+/*
+ * default format in which to save messages
+ */
+static int mbx_style = MBOX_FORMAT;
+
 
 main (int argc, char **argv)
 {
     int md;
     char *cp, *file = NULL, buf[100];
-    char ddate[BUFSIZ], **ap, **argp;
+    char **ap, **argp;
     char *arguments[MAXARGS];
 
 #ifdef LOCALE
@@ -57,6 +66,13 @@ main (int argc, char **argv)
 		case VERSIONSW:
 		    print_version(invo_name);
 		    done (1);
+
+		case MBOXSW:
+		    mbx_style = MBOX_FORMAT;
+		    continue;
+		case MMDFSW:
+		    mbx_style = MMDF_FORMAT;
+		    continue;
 	    }
 	if (file)
 	    adios (NULL, "only one file at a time!");
@@ -67,15 +83,18 @@ main (int argc, char **argv)
     if (!file)
 	adios (NULL, "%s [switches] file", invo_name);
 
-    sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
     rewind (stdin);
-    if ((md = mbx_open (file, getuid (), getgid (), m_gmprot ())) == NOTOK
-	    || mbx_copy (file, md, fileno (stdin), 1, ddate, 0) == NOTOK
-	    || mbx_close (file, md) == NOTOK) {
-	if (md != NOTOK)
-	    mbx_close (file, md);
+
+    if ((md = mbx_open (file, mbx_style, getuid(), getgid(), m_gmprot())) == NOTOK)
+	done (RCV_MBX);
+
+    if (mbx_copy (file, mbx_style, md, fileno(stdin), 1, NULL, 0) == NOTOK) {
+	mbx_close (file, md);
 	done (RCV_MBX);
     }
 
+    if (mbx_close (file, md) == NOTOK)
+	done (RCV_MBX);
+
     done (RCV_MOK);
 }
