@@ -10,6 +10,7 @@
 #endif
 
 #include <h/mh.h>
+#include <h/signals.h>
 #include <h/rcvmail.h>
 #include <h/scansbr.h>
 #include <zotnet/tws/tws.h>
@@ -18,6 +19,9 @@
 
 #ifndef	TTYD
 # include <utmp.h>
+# ifndef UTMP_FILE
+#  define UTMP_FILE "/etc/utmp"
+# endif
 #endif
 
 #define	SCANFMT	\
@@ -73,7 +77,7 @@ main (int argc, char **argv)
 #ifndef	TTYD
     char tty[BUFSIZ];
     struct utmp ut;
-    register FILE  *uf;
+    register FILE *uf;
 #endif	/* not TTYD */
 
 #ifdef LOCALE
@@ -146,7 +150,7 @@ main (int argc, char **argv)
 
     user = getusr();
 #ifndef	TTYD
-    if ((uf = fopen ("/etc/utmp", "r")) == NULL)
+    if ((uf = fopen (UTMP_FILE, "r")) == NULL)
 	exit (RCV_MBX);
     while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
 	if (ut.ut_name[0] != 0
@@ -155,9 +159,9 @@ main (int argc, char **argv)
 	    alert (tty, md);
 	}
     fclose (uf);
-#else	/* TTYD */
+#else /* TTYD */
     alert (user, md);
-#endif	/* TTYD */
+#endif /* TTYD */
 
     exit (RCV_MOK);
 }
@@ -187,43 +191,39 @@ message_fd (char **vec)
 	return header_fd ();
     unlink (tmpfil);
 
-    switch (child_id = vfork()) {
-	case NOTOK: 
-	    close (fd);
-	    return header_fd ();
-
-	case OK: 
-	    rewind (stdin);
-	    if (dup2 (fd, 1) == NOTOK || dup2 (fd, 2) == NOTOK)
-		_exit (-1);
-	    closefds (3);
-#ifdef BSD42
-	    setpgrp (0, getpid ());
-#endif
-	    execvp (vec[0], vec);
-	    _exit (-1);
-
-	default: 
-	    if (!setjmp (myctx)) {
-		SIGNAL (SIGALRM, alrmser);
-		bytes = fstat(fileno (stdin), &st) != NOTOK ? (int) st.st_size : 100;
-		if (bytes <= 0)
-		    bytes = 100;
-		alarm ((unsigned) (bytes * 60 + 300));
-
-		pidwait(child_id, OK);
-
-		alarm (0);
-		if (fstat (fd, &st) != NOTOK && st.st_size > (off_t)0)
-		    return fd;
-		close (fd);
-		return header_fd ();
-	    } else {
-		KILLPG(child_id, SIGKILL);
-		close (fd);
-		return header_fd ();
-	    }
+    if ((child_id = vfork()) == NOTOK) {
+	/* fork error */
+	close (fd);
+	return header_fd ();
+    } else if (child_id) {
+	/* parent process */
+	if (!setjmp (myctx)) {
+	    SIGNAL (SIGALRM, alrmser);
+	    bytes = fstat(fileno (stdin), &st) != NOTOK ? (int) st.st_size : 100;
+	    if (bytes <= 0)
+		bytes = 100;
+	    alarm ((unsigned) (bytes * 60 + 300));
+	    pidwait(child_id, OK);
+	    alarm (0);
+	    if (fstat (fd, &st) != NOTOK && st.st_size > (off_t) 0)
+		return fd;
+	} else {
+	    KILLPG(child_id, SIGKILL);
+	}
+	close (fd);
+	return header_fd ();
     }
+
+    /* child process */
+    rewind (stdin);
+    if (dup2 (fd, 1) == NOTOK || dup2 (fd, 2) == NOTOK)
+	_exit (-1);
+    closefds (3);
+#ifdef BSD42
+    setpgrp (0, getpid ());
+#endif
+    execvp (vec[0], vec);
+    _exit (-1);
 }
 
 
@@ -240,7 +240,7 @@ header_fd (void)
 
     rewind (stdin);
     scan (stdin, 0, 0, new_fs (form, format, SCANFMT), 0, 0, 0, 0, 0L, 0);
-    if ( newline )
+    if (newline)
         write (fd, "\n\r", 2);
     write (fd, scanl, strlen (scanl));
     if (bell)
@@ -251,22 +251,22 @@ header_fd (void)
 
 
 #ifndef	TTYD
+
 static void
 alert (char *tty, int md)
 {
-    int i, td;
+    int i, td, mask;
     char buffer[BUFSIZ], ttyspec[BUFSIZ];
     struct stat st;
 
     sprintf (ttyspec, "/dev/%s", tty);
-    if (stat (ttyspec, &st) == NOTOK ||
-	(st.st_mode & (biff ? S_IEXEC :
-#ifdef BSD43
-		       (S_IWRITE >> 3)
-#else /* BSD43 */
-		       02
-#endif /* BSD43 */
-		       )) == 0)
+
+    /*
+     * The mask depends on whether we are checking for
+     * write permission based on `biff' or `mesg'.
+     */
+    mask = biff ? S_IEXEC : (S_IWRITE >> 3);
+    if (stat (ttyspec, &st) == NOTOK || (st.st_mode & mask) == 0)
 	return;
 
     if (!setjmp (myctx)) {
@@ -290,7 +290,7 @@ alert (char *tty, int md)
     close (td);
 }
 
-#else	/* TTYD */
+#else /* TTYD */
 
 static void
 alert (char *user, int md)
@@ -309,5 +309,6 @@ alert (char *user, int md)
 
     close (td);
 }
-#endif	/* TTYD */
+
+#endif /* TTYD */
 
