@@ -7,6 +7,12 @@
 
 #include <h/mh.h>
 
+#ifdef MIME
+# define MIMEminc(a)  0
+#else
+# define MIMEminc(a) (a)
+#endif
+
 static struct swit switches[] = {
 #define	ANNOSW                 0
     { "annotate", 0 },
@@ -40,25 +46,29 @@ static struct swit switches[] = {
     { "inplace", 0 },
 #define	NINPLSW               15
     { "noinplace", 0 },
-#define	QURYSW                16
+#define MIMESW                16
+    { "mime", MIMEminc(-4) },
+#define NMIMESW               17
+    { "nomime", MIMEminc(-6) },
+#define	QURYSW                18
     { "query", 0 },
-#define	NQURYSW               17
+#define	NQURYSW               19
     { "noquery", 0 },
-#define	WHATSW                18
+#define	WHATSW                20
     { "whatnowproc program", 0 },
-#define	NWHATSW               19
+#define	NWHATSW               21
     { "nowhatnowproc", 0 },
-#define	WIDTHSW               20
+#define	WIDTHSW               22
     { "width columns", 0 },
-#define VERSIONSW             21
+#define VERSIONSW             23
     { "version", 0 },
-#define	HELPSW                22
+#define	HELPSW                24
     { "help", 4 },
-#define	FILESW                23
+#define	FILESW                25
     { "file file", -4 },		/* interface from msh */
 
 #ifdef MHE
-#define	BILDSW                24
+#define	BILDSW                26
     { "build", -5 },			/* interface from mhe */
 #endif
 
@@ -112,6 +122,8 @@ short format = 1;
 short outputlinelen = OUTPUTLINELEN;
 short querysw = 0;
 
+extern int mime;		/* include original as MIME part */
+
 char *fcc = NULL;		/* global for replsbr */
 char *filter = NULL;
 char *form = NULL;
@@ -201,10 +213,10 @@ main (int argc, char **argv)
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    nwhat = 0;
 		    continue;
-#ifdef	MHE
+#ifdef MHE
 		case BILDSW: 
 		    buildsw++;	/* fall... */
-#endif	/* MHE */
+#endif /* MHE */
 		case NWHATSW: 
 		    nwhat++;
 		    continue;
@@ -233,6 +245,7 @@ main (int argc, char **argv)
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    filter = getcpy (etcpath (cp));
+		    mime = 0;
 		    continue;
 		case FORMSW: 
 		    if (!(form = *argp++) || *form == '-')
@@ -253,6 +266,16 @@ main (int argc, char **argv)
 		    inplace = 0;
 		    continue;
 
+		case MIMESW:
+#ifdef MIME
+		    mime++;
+		    filter = NULL;
+#endif
+		    continue;
+		case NMIMESW:
+		    mime = 0;
+		    continue;
+
 		case QURYSW: 
 		    querysw++;
 		    continue;
@@ -310,11 +333,11 @@ try_it_again: ;
 #ifndef MHE
     strcpy (drft, m_draft (dfolder, dmsg, NOUSE, &isdf));
     if (stat (drft, &st) != NOTOK) {
-#else	/* MHE */
+#else /* MHE */
     strcpy (drft, buildsw ? m_maildir ("reply")
 			  : m_draft (dfolder, NULL, NOUSE, &isdf));
     if (!buildsw && stat (drft, &st) != NOTOK) {
-#endif	/* MHE */
+#endif /* MHE */
 	printf ("Draft \"%s\" exists (%ld bytes).", drft, st.st_size);
 	for (i = LISTDSW; i != YESW;) {
 	    if (!(argp = getans ("\nDisposition? ", isdf ? aqrnl : aqrl)))
@@ -378,7 +401,7 @@ go_to_it: ;
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
 
-    replout (in, msg, drft);
+    replout (in, msg, drft, mp);
     fclose (in);
 
     if (nwhat)
