@@ -373,12 +373,12 @@ invalid: ;
 		    if (*bp == NULL)
 			goto invalid;
 		    if (passno > 1) {
-			if (result = !uleq (bp, "plain"))
+			if ((result = !uleq (bp, "plain")))
 			    goto out;
 			*dp = c;
 			for (dp++; isspace (*dp); dp++)
 			    continue;
-			if (result = !uprf (dp, "charset"))
+			if ((result = !uprf (dp, "charset")))
 			    goto out;
 			dp += sizeof "charset" - 1;
 			while (isspace (*dp))
@@ -388,7 +388,7 @@ invalid: ;
 			while (isspace (*dp))
 			    dp++;
 			if (*dp == '"') {
-			    if (bp = strchr(++dp, '"'))
+			    if ((bp = strchr(++dp, '"')))
 				*bp = NULL;
 			}
 			else
