@@ -6,8 +6,6 @@
  */
 
 /*
- *  This program implements mail delivery in the MH/MMDF style.
- *
  *  Under sendmail, users should add the line
  *
  * 	"| /usr/local/nmh/lib/slocal"
@@ -87,8 +85,8 @@ static char *home = NULL;
 
 static struct passwd *pw;
 
+/* record the delivery date */
 static char ddate[BUFSIZ];
-
 struct tws *now;
 
 static jmp_buf myctx;
@@ -140,8 +138,8 @@ extern char **environ;
 /*
  * static prototypes
  */
-static int localmail (int, char *, char *);
-static int usr_delivery (int, char *, int, char *);
+static int localmail (int, char *);
+static int usr_delivery (int, char *, int);
 static int split (char *, char **);
 static int parse (int);
 static void expand (char *, char *, int);
@@ -149,7 +147,7 @@ static void glob (int);
 static struct pair *lookup (struct pair *, char *);
 static int logged_in (void);
 static int timely (char *, char *);
-static int usr_file (int, char *, char *);
+static int usr_file (int, char *, int);
 static int usr_pipe (int, char *, char *, char **);
 static RETSIGTYPE alrmser (int);
 static void copyinfo (FILE *fp, char *);
@@ -286,12 +284,18 @@ main (int argc, char **argv)
 
     setbuf (stdin, NULL);
 
+    /* Record the delivery time */
+    if ((now = dtwstime ()) == NULL)
+	adios (NULL, "unable to ascertain local time");
+    sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
+
     /*
      * Copy the message to a temporary file
      */
     if (file) {
 	int tempfd;
 
+	/* getting message from file */
 	if ((tempfd = open (file, O_RDONLY)) == -1)
 	    adios(file, "unable to open");
 	if (debug)
@@ -310,6 +314,7 @@ main (int argc, char **argv)
 	fprintf (stderr, "temporary file=\"%s\"\n", tmpfil);
     else
 	unlink (tmpfil);
+
     if (!(fp = fdopen (fd, "r+")))
 	adios (NULL, "unable to access temporary file");
 
@@ -326,10 +331,6 @@ main (int argc, char **argv)
     if (home == NULL)
 	home = pw->pw_dir;
 
-    if ((now = dtwstime ()) == NULL)
-	adios (NULL, "unable to ascertain local time");
-    sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
-
     if (debug) {
 	fprintf (stderr, "addr=\"%s\"\n", addr);
 	fprintf (stderr, "user=\"%s\"\n", user);
@@ -342,21 +343,25 @@ main (int argc, char **argv)
 	fprintf (stderr, "now=%02d:%02d\n\n", now->tw_hour, now->tw_min);
     }
 
-    result = localmail (fd, from, mdlvr);
+    result = localmail (fd, mdlvr);
     done (result != NOTOK ? RCV_MOK : RCV_MBX);
 }
 
 
 static int
-localmail (int fd, char *from, char *mdlvr)
+localmail (int fd, char *mdlvr)
 {
-    if (suppressdup && suppress_duplicates(fd, ".maildelivery") == DONE)
+    /* check if this message is a duplicate */
+    if (suppressdup &&
+        suppress_duplicates(fd, mdlvr ? mdlvr : ".maildelivery") == DONE)
 	return OK;
 
-    if (usr_delivery (fd, mdlvr ? mdlvr : ".maildelivery", 0, from) != NOTOK)
+    /* delivery according to personal Maildelivery file */
+    if (usr_delivery (fd, mdlvr ? mdlvr : ".maildelivery", 0) != NOTOK)
 	return OK;
 
-    if (usr_delivery (fd, maildelivery, 1, from) != NOTOK)
+    /* delivery according to global Maildelivery file */
+    if (usr_delivery (fd, maildelivery, 1) != NOTOK)
 	return OK;
 
 #if 0
@@ -368,21 +373,27 @@ localmail (int fd, char *from, char *mdlvr)
 
     if (verbose)
 	printf ("(trying normal delivery)\n");
-    return usr_file (fd, mbox, from);
+
+    /* delivery to standard mail spool */
+#ifdef RPATHS
+    return usr_file (fd, mbox, MBOX_FORMAT);
+#else
+    return usr_file (fd, mbox, MMDF_FORMAT);
+#endif
 }
 
 
 #define	matches(a,b) (stringdex (b, a) >= 0)
 
 static int
-usr_delivery (int fd, char *delivery, int su, char *from)
+usr_delivery (int fd, char *delivery, int su)
 {
     int i, accept, status, won, vecp, next;
-    register char *cp, *action, *field, *pattern, *string;
+    char *cp, *action, *field, *pattern, *string;
     char buffer[BUFSIZ], tmpbuf[BUFSIZ], *vec[NVEC];
     struct stat st;
-    register struct pair *p;
-    register FILE *fp;
+    struct pair *p;
+    FILE *fp;
 
     if ((fp = fopen (delivery, "r")) == NULL)
 	return NOTOK;
@@ -391,7 +402,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 	    || st.st_mode & (S_IWGRP|S_IWOTH)) {
 	if (verbose) {
 	    printf ("%s: ownership/modes bad (%d, %d,%d,0%o)\n",
-		    delivery, su, pw->pw_uid, st.st_uid, st.st_mode);
+		    delivery, su, (int) pw->pw_uid, (int) st.st_uid, (int) st.st_mode);
 	    fflush (stdout);
 	}
 	return NOTOK;
@@ -481,6 +492,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 
 	switch (*action) {
 	    case 'q':
+		/* deliver to quoted pipe */
 		if (!uleq (action, "qpipe"))
 		    continue;	/* else fall */
 	    case '^':
@@ -491,6 +503,7 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		break;
 
 	    case 'p': 
+		/* deliver to pipe */
 		if (!uleq (action, "pipe"))
 		    continue;	/* else fall */
 	    case '|': 
@@ -502,8 +515,16 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		status = usr_pipe (fd, tmpbuf, "/bin/sh", vec + 2);
 		break;
 
+	    case 'f': 
+		/* mbox format */
+		if (uleq (action, "file")) {
+		    status = usr_file (fd, string, MBOX_FORMAT);
+		    break;
+		}
+		/* deliver to folder */
+		else if (!uleq (action, "folder"))
+		    continue;	/* else fall */
 	    case '+':
-	    dofolder:
 		if (*string == '+')
 		    strcpy(tmpbuf, string);
 		else
@@ -516,23 +537,19 @@ usr_delivery (int fd, char *delivery, int su, char *from)
 		status = usr_pipe(fd, "rcvstore", rcvstoreproc, vec + 2);
 		break;
 
-	    case 'f': 
-		if (uleq(action, "folder"))
-		    goto dofolder;
-		if (!uleq (action, "file"))
-		    continue;	/* else fall */
-	    case '>': 
-#ifdef RPATHS
-		status = usr_file (fd, string,  from);	/* UUCP format? */
-#else
-		status = usr_file (fd, string,  NULL);
-#endif
-		break;
-
 	    case 'm':
-		if (!uleq (action, "mbox"))
-		    continue;
-		status = usr_file (fd, string,  NULL);
+		/* mmdf format */
+		if (uleq (action, "mmdf")) {
+		    status = usr_file (fd, string, MMDF_FORMAT);
+		    break;
+		}
+		/* mbox format */
+		else if (!uleq (action, "mbox"))
+		    continue;	/* else fall */
+
+	    case '>': 
+		/* mbox format */
+		status = usr_file (fd, string, MBOX_FORMAT);
 		break;
 
 	    case 'd': 
@@ -618,13 +635,13 @@ parse (int fd)
 	p->p_value = getcpy (addr);
 
     for (i = 0, state = FLD;;) {
-	switch (state = m_getfld (state, name, field, sizeof field, in)) {
+	switch (state = m_getfld (state, name, field, sizeof(field), in)) {
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
 		lp = add (field, NULL);
 		while (state == FLDPLUS) {
-		    state = m_getfld (state, name, field, sizeof field, in);
+		    state = m_getfld (state, name, field, sizeof(field), in);
 		    lp = add (field, lp);
 		}
 		for (p = hdrs; p->p_name; p++)
@@ -778,9 +795,9 @@ logged_in (void)
     if ((uf = fopen ("/etc/utmp", "r")) == NULL)
 	return NOTOK;
 
-    while (fread ((char *) &ut, sizeof ut, 1, uf) == 1)
+    while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
 	if (ut.ut_name[0] != 0
-		&& strncmp (user, ut.ut_name, sizeof ut.ut_name) == 0) {
+		&& strncmp (user, ut.ut_name, sizeof(ut.ut_name)) == 0) {
 	    if (debug)
 		continue;
 	    fclose (uf);
@@ -818,37 +835,34 @@ timely (char *t1, char *t2)
 
 
 static int
-usr_file (int fd, char *mailbox, char *from)
+usr_file (int fd, char *mailbox, int mbx_style)
 {
     int	md, mapping;
-    register char *bp;
-    char buffer[BUFSIZ];
 
     if (verbose)
 	printf ("\tdelivering to file \"%s\"", mailbox);
-    if (from && *from) {
-	mbx_uucp ();
+
+    if (mbx_style == MBOX_FORMAT) {
 	if (verbose)
-	    printf (" (uucp style)");
-	sprintf (buffer, "%s%s", from, ddate);
-	bp = buffer;
+	    printf (" (mbox style)");
 	mapping = 0;
-    }
-    else {
-	bp = ddate;
+    } else {
+	if (verbose)
+	    printf (" (mmdf style)");
 	mapping = 1;
     }
+
     if (verbose)
 	fflush (stdout);
 
-    if ((md = mbx_open (mailbox, pw->pw_uid, pw->pw_gid, m_gmprot ()))
+    if ((md = mbx_open (mailbox, mbx_style, pw->pw_uid, pw->pw_gid, m_gmprot()))
 	    == NOTOK) {
 	adorn ("", "unable to open:");
 	return NOTOK;
     }
 
     lseek (fd, (off_t) 0, SEEK_SET);
-    if (mbx_copy (mailbox, md, fd, mapping, bp, verbose) == NOTOK) {
+    if (mbx_copy (mailbox, mbx_style, md, fd, mapping, NULL, verbose) == NOTOK) {
 	adorn ("", "error writing to:");
 	return NOTOK;
     }
@@ -930,10 +944,12 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	sleep (5);
     switch (child_id) {
 	case NOTOK: 
+	    /* fork error */
 	    adorn ("fork", "unable to");
 	    return NOTOK;
 
 	case OK: 
+	    /* child process */
 	    if (fd != 0)
 		dup2 (fd, 0);
 	    freopen ("/dev/null", "w", stdout);
@@ -962,6 +978,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    _exit (-1);
 
 	default: 
+	    /* parent process */
 	    if (!setjmp (myctx)) {
 		SIGNAL (SIGALRM, alrmser);
 		bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
@@ -1009,6 +1026,11 @@ alrmser (int i)
 }
 
 
+/*
+ * Get the `sender' info from the
+ * "From " line.
+ */
+
 static void
 copyinfo (FILE *fp, char *from)
 {
@@ -1016,12 +1038,14 @@ copyinfo (FILE *fp, char *from)
     register char *cp;
     static char buffer[BUFSIZ];
 
-    if (unixfrom)	/* interface from copyfile */
+    /* copy of the "From " line from copyfile */
+    if (unixfrom)
 	strcpy (from, unixfrom);
     else if (fgets (from, BUFSIZ, fp) == NULL)
 	adios (NULL, "no message");
 
-    if (strncmp (from, "From ", i = strlen ("From "))) {
+    i = strlen ("From ");
+    if (strncmp (from, "From ", i)) {
 	rewind (fp);
 	*from = 0;
 	return;
@@ -1048,6 +1072,11 @@ copyinfo (FILE *fp, char *from)
 }
 
 
+/*
+ * Copy message into a temporary file,
+ * and do processing of the message headers.
+ */
+
 static int
 copyfile (int qd, char *tmpfil, int fold)
 {
@@ -1056,11 +1085,13 @@ copyfile (int qd, char *tmpfil, int fold)
     register FILE *qfp, *ffp;
 
     strcpy (tmpfil, m_tmpfil (invo_name));
+
+    /* open temporary file to put message in */
     if ((fd1 = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	return NOTOK;
 
     if (!fold) {
-	while ((i = read (qd, buffer, sizeof buffer)) > 0)
+	while ((i = read (qd, buffer, sizeof(buffer))) > 0)
 	    if (write (fd1, buffer, i) != i) {
 you_lose: ;
 		close (fd1);
@@ -1073,21 +1104,27 @@ you_lose: ;
 	return fd1;
     }
 
+    /* dup the fd for incoming message */
     if ((fd2 = dup (qd)) == NOTOK) {
 	close (fd1);
 	return NOTOK;
     }
+
+    /* now create a FILE pointer for it */
     if ((qfp = fdopen (fd2, "r")) == NULL) {
 	close (fd1);
 	close (fd2);
 	return NOTOK;
     }
 
+    /* dup the fd for temporary file */
     if ((fd2 = dup (fd1)) == NOTOK) {
 	close (fd1);
 	fclose (qfp);
 	return NOTOK;
     }
+
+    /* now create a FILE pointer for it */
     if ((ffp = fdopen (fd2, "r+")) == NULL) {
 	close (fd1);
 	close (fd2);
@@ -1095,17 +1132,36 @@ you_lose: ;
 	return NOTOK;
     }
 
+    /*
+     * copy message into temporary file
+     * and massage the headers
+     */
     i = strlen ("From ");
     while (fgets (buffer, sizeof(buffer), qfp)) {
-	if (!strncmp (buffer, "From ", i))
+	if (!strncmp (buffer, "From ", i)) {
 	    if (first == 0) {
 #ifdef RPATHS
-		register char *fp, *cp, *hp, *ep;
+		char *fp, *cp, *hp, *ep;
 #endif
-		unixfrom = getcpy (buffer);     /* save for later */
-#ifndef RPATHS
-		continue;                       /* but don't put in file */
-#else
+		/* save "From " line for later */
+		unixfrom = getcpy (buffer);
+#ifdef RPATHS
+		/* First go ahead and put "From " line in message */
+		fputs (buffer, ffp);
+		if (ferror (ffp))
+		    goto fputs_error;
+#endif
+
+		/* Now put the delivery date in message */
+		fputs (ddate, ffp);
+		if (ferror (ffp))
+		    goto fputs_error;
+
+#ifdef RPATHS
+		/*
+		 * Now create a "Return-Path:" line from
+		 * the "From " line and add it.
+		 */
 		hp = cp = strchr(fp = unixfrom + i, ' ');
 		while ((hp = strchr(++hp, 'r')))
 		    if (uprf (hp, "remote from")) {
@@ -1114,27 +1170,21 @@ you_lose: ;
 		    }
 		if (hp) {
 		    ep = strrchr(++hp, '\n');
-		    sprintf (buffer, "Return-Path: %.*s!%.*s\n",
-			    ep - hp, hp,
-			    cp - fp, fp);
+		    sprintf (buffer, "Return-Path: %.*s!%.*s\n", ep - hp, hp, cp - fp, fp);
+		} else {
+		    sprintf (buffer, "Return-Path: %.*s\n", cp - fp, fp);
 		}
-		else
-		    sprintf (buffer, "Return-Path: %.*s\n",
-			    cp - fp, fp);
+#else
+		/* but don't put it in the file */
+		continue;
 #endif
 	    }
-#ifdef	notdef		/* mbx_copy does this */
-	    else
-		putc ('>', ffp);
-#endif	/* notdef */
+	}
+
 	first++;
 	fputs (buffer, ffp);
-	if (ferror (ffp)) {
-	    close (fd1);
-	    fclose (ffp);
-	    fclose (qfp);
-	    return NOTOK;
-	}
+	if (ferror (ffp))
+	    goto fputs_error;
     }
 
     fclose (ffp);
@@ -1144,10 +1194,15 @@ you_lose: ;
 	return NOTOK;
     }
     fclose (qfp);
-
     lseek (fd1, (off_t) 0, SEEK_SET);
-
     return fd1;
+
+
+fputs_error:
+    close (fd1);
+    fclose (ffp);
+    fclose (qfp);
+    return NOTOK;
 }
 
 
@@ -1181,7 +1236,7 @@ adorn (char *what, char *fmt, ...)
 static int
 suppress_duplicates (int fd, char *file)
 {
-    int	fd1, state;
+    int	fd1, lockfd, state, result;
     char *cp, buf[BUFSIZ], name[NAMESZ];
     datum key, value;
     DBM *db;
@@ -1196,23 +1251,24 @@ suppress_duplicates (int fd, char *file)
     rewind (in);
 
     for (state = FLD;;) {
-	state = m_getfld (state, name, buf, sizeof buf, in);
+	state = m_getfld (state, name, buf, sizeof(buf), in);
 	switch (state) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
 		if (!uleq (name, "Message-ID")) {
 		    while (state == FLDPLUS)
-			state = m_getfld (state, name, buf, sizeof buf, in);
+			state = m_getfld (state, name, buf, sizeof(buf), in);
 		    continue;
 		}
 
 		cp = add (buf, NULL);
 		while (state == FLDPLUS) {
-		    state = m_getfld (state, name, buf, sizeof buf, in);
+		    state = m_getfld (state, name, buf, sizeof(buf), in);
 		    cp = add (buf, cp);
 		}
-		key.dsize = strlen (key.dptr = trimcpy (cp)) + 1;
+		key.dptr = trimcpy (cp);
+		key.dsize = strlen (key.dptr) + 1;
 		free (cp);
 		cp = key.dptr;
 
@@ -1222,35 +1278,35 @@ suppress_duplicates (int fd, char *file)
 		    fclose (in);
 		    return NOTOK;
 		}
-		if (lockfile(dbm_pagfno(db)) == -1) {
+		/*
+		 * Since it is difficult to portable lock a ndbm
+		 * file, we will lock the Maildelivery file instead.
+		 */
+		if ((lockfd = lkopen(file, O_RDWR)) == -1) {
 		    advise (file, "unable to perform file locking on");
 		    free (cp);
 		    fclose (in);
 		    return NOTOK;
 		}
-
 		value = dbm_fetch (db, key);
 		if (value.dptr) {
 		    if (verbose)
-		        printf ("Message-ID: %s already received\non Date: %s", cp, value.dptr);
-		    free (cp);
-		    fclose (in);
-		    return DONE;
+		        printf ("Message-ID: %s\n            already received on %s",
+				 cp, value.dptr);
+		    result = DONE;
+		} else {
+		    value.dptr  = ddate + sizeof("Delivery-Date:");
+		    value.dsize = strlen(value.dptr) + 1;
+		    if (dbm_store (db, key, value, DBM_INSERT))
+			advise (file, "possibly corrupt file");
+		    result = OK;
 		}
-			   
-		value.dptr  = ddate + sizeof("Delivery-Date:");
-		value.dsize = strlen(value.dptr) + 1;
 
-		if (dbm_store (db, key, value, DBM_INSERT))
-		    advise (file, "possibly corrupt file");
-
-		/*
-		 * no need to unlock the dbm file(s), since we
-		 * immediately close them anyway.
-		 */
 		dbm_close (db);
-
+		lkclose(lockfd, file);
 		free (cp);
+		fclose (in);
+		return result;
 		break;
 
 	   case BODY:
