@@ -132,8 +132,8 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
 	*ap = NULL;
     }
 
-    nz = (ne = nets) + sizeof nets / sizeof nets[0];
-    hz = (he = hosts) + sizeof hosts / sizeof hosts[0];
+    nz = (ne = nets) + sizeof(nets) / sizeof(nets[0]);
+    hz = (he = hosts) + sizeof(hosts) / sizeof(hosts[0]);
 
     for (ap = arguments; *ap; ap++) {
 	if (**ap == '\01') {
@@ -206,19 +206,19 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
     if ((sd = getport (rproto, hp->h_addrtype, response)) == NOTOK)
 	return OOPS2;
 
-    memset((char *) isock, 0, sizeof *isock);
+    memset((char *) isock, 0, sizeof(*isock));
     isock->sin_family = hp->h_addrtype;
     inaddr_copy (hp, isock);
     isock->sin_port = sp->s_port;
 
-    if (connect (sd, (struct sockaddr *) isock, sizeof *isock) == NOTOK)
+    if (connect (sd, (struct sockaddr *) isock, sizeof(*isock)) == NOTOK)
 	switch (errno) {
 	    case ENETDOWN: 
 	    case ENETUNREACH: 
 		close (sd);
 		if (ne < nz) {
 		    ne->a_addrtype = hp->h_addrtype;
-		    memcpy((char *) &in, hp->h_addr, sizeof in);
+		    memcpy((char *) &in, hp->h_addr, sizeof(in));
 		    ne->a_net = inet_netof (in);
 		    ne++;
 		}
@@ -288,11 +288,11 @@ getport (int rproto, int addrtype, char *response)
     if (!rproto)
 	return sd;
 
-    memset((char *) isock, 0, sizeof *isock);
+    memset((char *) isock, 0, sizeof(*isock));
     isock->sin_family = addrtype;
     for (port = IPPORT_RESERVED - 1;;) {
 	isock->sin_port = htons ((ushort) port);
-	if (bind (sd, (struct sockaddr *) isock, sizeof *isock) != NOTOK)
+	if (bind (sd, (struct sockaddr *) isock, sizeof(*isock)) != NOTOK)
 	    return sd;
 
 	switch (errno) {
@@ -322,7 +322,7 @@ inet (struct hostent *hp, int net)
 {
     struct in_addr in;
 
-    memcpy((char *) &in, hp->h_addr, sizeof in);
+    memcpy((char *) &in, hp->h_addr, sizeof(in));
     return (inet_netof (in) == net);
 }
 
@@ -358,10 +358,10 @@ gethostbystring (char *s)
     h->h_name = s;
     h->h_aliases = &empty;
     h->h_addrtype = AF_INET;
-    h->h_length = sizeof (iaddr);
+    h->h_length = sizeof(iaddr);
 #ifdef h_addr
     h->h_addr_list = addrs;
-    memset((char *) addrs, 0, sizeof addrs);
+    memset((char *) addrs, 0, sizeof(addrs));
 #endif
     h->h_addr = (char *) &iaddr;
 
